#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.8.0
visibility:           public
id:                   tasty-checklist-1.0.8.0-sH5btcYztELd90yMUviQ7
key:                  tasty-checklist-1.0.8.0-sH5btcYztELd90yMUviQ7
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  c06bea52351bf4d191219fcb31d81d42
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.8.0-sH5btcYztELd90yMUviQ7
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7
    parameterized-utils-2.1.11.0-FT6hinG6I3yIuyxwZnMwuh text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

